@@ -2,10 +2,15 @@ import os
 
 
 def read_folder(folder, mode):
+    if 'b' in mode:
+        encoding = None
+    else:
+        encoding = 'utf-8'
+
     for folder, __, files in os.walk(folder):
         for file_name in files:
             path = os.path.join(folder, file_name)
-            with open(path, mode) as fo:
+            with open(path, mode, encoding=encoding) as fo:
                 yield path, fo.read()
 
 
